@@ -21,6 +21,7 @@ def add_date_features(df, date_var, drop = True, time = False):
     --------------------
     Returns:
     - pandas DF with new features
+
     '''
     
     fld = df[date_var]
@@ -63,12 +64,13 @@ def add_date_features(df, date_var, drop = True, time = False):
 
 import pandas as pd
 from sklearn.feature_extraction.text import TfidfVectorizer, CountVectorizer
+import scipy.sparse
 
 def add_text_features(df, 
                       string_vars, 
                       tf_idf_feats = 5, 
-                      common_words = 10,
-                      rare_words = 10,
+                      common_words = 0,
+                      rare_words = 0,
                       drop = True):
     '''
     Adds basic text-based features including word count, character count and 
@@ -86,6 +88,24 @@ def add_text_features(df,
     --------------------
     Returns:
     - pandas DF with new features
+
+    --------------------
+    Examples:
+
+    # import dependecies
+    import pandas as pd
+    import numpy as np
+
+    # create data frame
+    data = {'age': [27, np.nan, 30, 25, np.nan], 
+        'height': [170, 168, 173, 177, 165], 
+        'gender': ['female', 'male', np.nan, 'male', 'female'],
+        'income': ['high', 'medium', 'low', 'low', 'no income']}
+    df = pd.DataFrame(data)
+
+    # add text features
+    from dptools import add_text_features
+    df_new = add_text_features(df, string_vars = ['income', 'gender])
     '''
 
     ##### PROCESSING LOOP
@@ -95,7 +115,7 @@ def add_text_features(df,
         ### TEXT PREPROCESSING
 
         # replace NaN with empty string
-        df[var][pd.isnull(df[var])] = ''
+        df[var].fillna('', inplace = True)
 
         # remove common and rare words
         freq = pd.Series(' '.join(df[var]).split()).value_counts()[:common_words]
@@ -130,7 +150,7 @@ def add_text_features(df,
 
         # compute TF-IDF
         vals = tfidf.fit_transform(df[var])
-        vals = pd.SparsedfFrame(vals)
+        vals = pd.DataFrame.sparse.from_spmatrix(vals)
         vals.columns = [var + '_tfidf_' + str(p) for p in vals.columns]
         df = pd.concat([df, vals], axis = 1)
 
